function ArenaLive_AbsorbBar_Initialise (absorbBar, absorbOverlay, absorbFullHPIndicator)
	if (not absorbBar ) then
		return;
	end
	
	if ( absorbOverlay ) then
		absorbBar.absorbOverlay = absorbOverlay;
		absorbBar.absorbOverlay:SetAllPoints(absorbBar);
		absorbBar.absorbOverlay.tileSize = 32;
		
	end
	
	if ( absorbFullHPIndicator ) then
		absorbBar.absorbFullHPIndicator = absorbFullHPIndicator;
	end
end
	
function ArenaLive_AbsorbBar_Update (unitFrame)

	if ( not unitFrame.absorbBar or not unitFrame.healthBar ) then
		return;
	end	
	
	if ( not unitFrame.unit ) then
		unitFrame.absorbBar:Hide();
		if ( unitFrame.absorbBarOverlay ) then
			unitFrame.absorbBarOverlay:Hide();
		end
		if ( unitFrame.absorbFullHPIndicator ) then
			unitFrame.absorbFullHPIndicator:Hide();
		end	
		return;
	end
	
	if ( not ARENALIVE_DATABASE[unitFrame.addonName]["options"]["showHealPrediction"] or not unitFrame.unit ) then
		unitFrame.absorbBar:Hide();
		if ( unitFrame.absorbBarOverlay ) then
			unitFrame.absorbBarOverlay:Hide();
		end
		if ( unitFrame.absorbFullHPIndicator ) then
			unitFrame.absorbFullHPIndicator:Hide();
		end	
		return;
	else
		
		local absorb = UnitGetTotalAbsorbs(unitFrame.unit) or 0;
	
		local health = UnitHealth(unitFrame.unit);
		local minHealth = unitFrame.healthBar:GetMinMaxValues();
		local maxHealth = UnitHealthMax(unitFrame.unit);
		local oldMaxHealth;
		
		-- If maxhealth is smaller than current health and absorb combined, we stretch set the new maxValue.
		if ( health + absorb > maxHealth ) then
			oldMaxHealth = maxHealth;
			maxHealth = health + absorb;
			
			-- We set a small line to indicate the 100% HP mark, when current HP + Absobr > Max-HP
			if ( unitFrame.absorbFullHPIndicator ) then
				unitFrame.absorbFullHPIndicator:Show();
			end
		else
			if ( unitFrame.absorbFullHPIndicator ) then
				unitFrame.absorbFullHPIndicator:Hide();
			end		
		end
		
		unitFrame.healthBar:SetMinMaxValues(minHealth, maxHealth);
		
		if ( absorb == 0 ) then
			unitFrame.absorbBar:Hide();
			
			if ( unitFrame.absorbBarOverlay ) then
				unitFrame.absorbBarOverlay:Hide();
			end
		else
			unitFrame.absorbBar:ClearAllPoints();

			if ( unitFrame.healthBar:GetReverseFill() ) then
				unitFrame.absorbBar:SetPoint("TOPRIGHT", unitFrame.healthBar:GetStatusBarTexture(), "TOPLEFT", 0, 0);
				unitFrame.absorbBar:SetPoint("BOTTOMRIGHT", unitFrame.healthBar:GetStatusBarTexture(), "BOTTOMLEFT", 0, 0);
			else
				unitFrame.absorbBar:SetPoint("TOPLEFT", unitFrame.healthBar:GetStatusBarTexture(), "TOPRIGHT", 0, 0);
				unitFrame.absorbBar:SetPoint("BOTTOMLEFT", unitFrame.healthBar:GetStatusBarTexture(), "BOTTOMRIGHT", 0, 0);
			end

			local totalWidth, totalHeight = unitFrame.healthBar:GetSize();
			local _, totalMax = unitFrame.healthBar:GetMinMaxValues();

			local barWidth = (absorb / totalMax) * totalWidth;
			unitFrame.absorbBar:SetWidth(barWidth);
			unitFrame.absorbBar:Show();
			
			if ( unitFrame.absorbBarOverlay ) then
				unitFrame.absorbBarOverlay:SetTexCoord(0, barWidth / unitFrame.absorbBarOverlay.tileSize, 0, totalHeight / unitFrame.absorbBarOverlay.tileSize);
				unitFrame.absorbBarOverlay:Show();
			end
			
			if ( unitFrame.absorbFullHPIndicator and unitFrame.absorbFullHPIndicator:IsShown() ) then
				
				local xOffset = (oldMaxHealth / totalMax ) * totalWidth;
				unitFrame.absorbFullHPIndicator:ClearAllPoints();
				
				if ( unitFrame.healthBar:GetReverseFill() ) then
					unitFrame.absorbFullHPIndicator:SetPoint("TOPRIGHT", unitFrame.healthBar:GetStatusBarTexture(), "TOPRIGHT", -xOffset, 0);
				else
					unitFrame.absorbFullHPIndicator:SetPoint("TOPLEFT", unitFrame.healthBar:GetStatusBarTexture(), "TOPLEFT", xOffset, 0);
				end
				
				unitFrame.absorbFullHPIndicator:SetHeight(unitFrame.healthBar:GetHeight());
			end
		end
	end
end