function ArenaLive_HealthBar_Initialise (healthBar, healthBarText, addonName, frameType)

	if ( not healthBar ) then
		return;
	end
	
	healthBar.frameType = frameType;
	healthBar.addonName = addonName;
	healthBar.showDeadorGhostText = true;
	ArenaLive_StatusBarText_SetStatusBarTextString(healthBar, healthBarText);
	
	healthBar:RegisterEvent("UNIT_MAXHEALTH");
end


function ArenaLive_HealthBar_SetBarColour (healthBar, frameType)

	if ( not healthBar ) then
		return;
	end

	local colourMode = ARENALIVE_DATABASE[healthBar.addonName]["frameTypes"][frameType]["healthBarColourMode"];
	
	local isPlayer = UnitIsPlayer(healthBar.unit);
	-- If the Unit is an NPC we fall back to ReactionColour. If it still isn't working we use green.
	if ( colourMode == "byClass" and isPlayer ) then
	
		if ( not healthBar.unit) then
			healthBar:SetStatusBarColor(0, 1, 0);
		end
		
		local _, class = UnitClass(healthBar.unit);
		
		
		if ( class ) then		
			healthBar:SetStatusBarColor(RAID_CLASS_COLORS[class].r, RAID_CLASS_COLORS[class].g, RAID_CLASS_COLORS[class].b);
		else
			
			local red, green, blue = UnitSelectionColor(healthBar.unit)
			
			if ( red ) then
				healthBar:SetStatusBarColor(red, green, blue);
			else
				healthBar:SetStatusBarColor(0, 1, 0);
			end
		end
		
	elseif ( colourMode == "byReaction" or ( colourMode == "byClass" and not isPlayer ) ) then
		
		if ( not healthBar.unit) then
			healthBar:SetStatusBarColor(0, 1, 0);
		end	
		
		local red, green, blue = UnitSelectionColor(healthBar.unit);
		
		if ( red ) then
			healthBar:SetStatusBarColor(red, green, blue);
		else
			healthBar:SetStatusBarColor(0, 1, 0);
		end
	
	else
		healthBar:SetStatusBarColor(0, 1, 0);
	end
end



function ArenaLive_HealthBar_OnEvent (self, event, ...)

	if ( not self.ignoreNoUnit or UnitGUID(self.unit) ) then
		ArenaLive_HealthBar_Update(self, ...);
	end
	
end



function ArenaLive_HealthBar_OnUpdate (self, elapsed)

	if ( not self.disconnected and not self.lockValues) then
		local currValue = UnitHealth(self.unit);
		if ( currValue ~= self.currValue ) then
			if ( not self.ignoreNoUnit or UnitGUID(self.unit) ) then
				self:SetValue(currValue);
				self.currValue = currValue;
				ArenaLive_AbsorbBar_Update(self:GetParent());
			end
		end
	end

end

function ArenaLive_HealthBar_OnValueChanged(self)
	local value = self:GetValue();
	
	local minValue, maxValue;
	if ( self.unit ) then
		maxValue = UnitHealthMax(self.unit);
		minValue = self:GetMinMaxValues();
	else
		minValue, maxValue = self:GetMinMaxValues();
	end
	ArenaLive_StatusBarText_UpdateText(self, ARENALIVE_DATABASE[self.addonName]["frameTypes"][self.frameType]["healthBarTextString"], minValue, maxValue, value);

end

function ArenaLive_HealthBar_Update (healthBar, unit)

	if ( not healthBar or healthBar.lockValues ) then
		return;
	end

	if ( unit == healthBar.unit ) then
	
		local maxValue = UnitHealthMax(unit);
		healthBar.forceHideText = false;
		
		if ( maxValue == 0 ) then
			maxValue = 1;
			healthBar.forceHideText = true;
		end
	
		healthBar:SetMinMaxValues(0, maxValue);

		healthBar.disconnected = not UnitIsConnected(unit);
		if ( healthBar.disconnected ) then
			if ( not healthBar.lockColor ) then
				healthBar:SetStatusBarColor(0.5, 0.5, 0.5);
			end
			healthBar:SetValue(maxValue);
			healthBar.currValue = maxValue;
		else
			local currValue = UnitHealth(unit);
			if ( not healthBar.lockColor ) then
				ArenaLive_HealthBar_SetBarColour(healthBar, healthBar.frameType)
			end
			healthBar:SetValue(currValue);
			healthBar.currValue = currValue;
		end
	end
		
end



-- Function for dynamic unitID unit frames
function ArenaLive_HealthBar_Reset (healthBar)
	healthBar:SetMinMaxValues(0, 1);
	healthBar:SetValue(1);
	healthBar:SetStatusBarColor(0.5, 0.5, 0.5);
end