function ArenaLive_PowerBar_Initialise (powerBar, powerBarText, addonName, frameType)

	if ( not powerBar ) then
		return;
	end
	
	powerBar.addonName = addonName;
	powerBar.frameType = frameType;
	powerBar.alwaysShowText = true;
	ArenaLive_StatusBarText_SetStatusBarTextString(powerBar, powerBarText);	

	powerBar:RegisterEvent("UNIT_DISPLAYPOWER");
	powerBar:RegisterEvent("UNIT_MAXPOWER");	
	
end



function ArenaLive_PowerBar_UpdatePowerType (powerBar)

	if ( not powerBar ) then
		return;
	end
	
	local powerType, powerToken, altR, altG, altB = UnitPowerType(powerBar.unit);
	local info = PowerBarColor[powerToken];
	
	if ( info ) then
		if ( not powerBar.lockColor ) then
			powerBar:SetStatusBarColor(info.r, info.g, info.b);
		end	
	else
		if ( not altR) then

			info = PowerBarColor[powerType] or PowerBarColor["MANA"];
		else
			if ( not powerBar.lockColor ) then
				powerBar:SetStatusBarColor(altR, altG, altB);
			end
		end
	end
	
	powerBar.powerType = powerType;

end



function ArenaLive_PowerBar_OnEvent (self, event, ...)
	
		if ( not self.ignoreNoUnit or UnitGUID(self.unit) ) then
			ArenaLive_PowerBar_Update(self, ...);
		end
end



function ArenaLive_PowerBar_OnUpdate(self, elapsed)
	if ( not self.disconnected and not self.lockValues ) then
		local currValue = UnitPower(self.unit, self.powerType);
		if ( currValue ~= self.currValue ) then
			if ( not self.ignoreNoUnit or UnitGUID(self.unit) ) then
				self:SetValue(currValue);
				self.currValue = currValue;
				ArenaLive_StatusBarText_UpdateText(self, ARENALIVE_DATABASE[self.addonName]["frameTypes"][self.frameType]["powerBarTextString"]);
			end
		end
	end
end

function ArenaLive_PowerBar_OnValueChanged(self)
	local value = self:GetValue();
	local minValue, maxValue = self:GetMinMaxValues();

	ArenaLive_StatusBarText_UpdateText(self, ARENALIVE_DATABASE[self.addonName]["frameTypes"][self.frameType]["powerBarTextString"], minValue, maxValue, value);
end

function ArenaLive_PowerBar_Update (powerBar, unit)

	if ( not powerBar or powerBar.lockValues ) then
		return;
	end
	
	if ( unit == powerBar.unit ) then
		-- be sure to update the power type before grabbing the max power!
		ArenaLive_PowerBar_UpdatePowerType(powerBar);

		local maxValue = UnitPowerMax(unit, powerBar.powerType);
		powerBar.forceHideText = false;
		
		if (maxValue == 0 ) then
			maxValue = 1;
			powerBar.forceHideText = true;
		end
		
		powerBar:SetMinMaxValues(0, maxValue);

		powerBar.disconnected = not UnitIsConnected(unit);
		if ( powerBar.disconnected ) then
			if ( not powerBar.lockColor ) then
				powerBar:SetStatusBarColor(0.5, 0.5, 0.5);
			end
			powerBar:SetValue(maxValue);
			powerBar.currValue = maxValue;
		else
			local currValue = UnitPower(unit, powerBar.powerType);
			powerBar:SetValue(currValue);
			powerBar.currValue = currValue;
		end
	end

	ArenaLive_StatusBarText_UpdateText(powerBar, ARENALIVE_DATABASE[powerBar.addonName]["frameTypes"][powerBar.frameType]["powerBarTextString"]);
	
end


-- Function for dynamic unitID frames that are shown even if they are not filled with unit data.
function ArenaLive_PowerBar_Reset (powerBar)

	powerBar:SetMinMaxValues(0, 1);
	powerBar:SetValue(1);
	powerBar:SetStatusBarColor(0.5, 0.5, 0.5);

end