local addonName, L = ...;

function ALUF_OptionsFocusFrame_OnLoad(self)
	-- Create a sub panel in ArenaLiveUnitFrame addon panel
	self.name= L["focusFrame"];
	self.okay = ALUF_OptionsFocusFrame_Okay;
	self.cancel = ALUF_OptionsFocusFrame_Cancel;
	self.parent = "ArenaLiveUnitFrames";
	InterfaceOptions_AddCategory(self);	

	-- Set Localisation:
	ALUF_FocusFrame_OptionsTitle:SetText(L["ALUFFocusFrameTitle"]);
	ALUF_FocusFrame_OptionsCastBarTitle:SetText(L["castBar:"]);
	ALUF_FocusFrame_OptionsAuraTitle:SetText(L["auras:"]);
	
	self:RegisterEvent("ADDON_LOADED");
end

function ALUF_OptionsFocusFrame_Initialise(self)
	local prefix = self:GetName();
	local checkbutton, editbox, slider, dropdown, selectedValue;
	
	-- Initialise Checkbuttons
	checkbutton = _G[prefix.."IsEnabled"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "enableFrame", "focusFrame", nil, "enabled");
	
	checkbutton = _G[prefix.."IsLocked"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "lockFrame", "focusFrame", nil, "isLocked");
	
	checkbutton = _G[prefix.."ShowCastBar"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "showCastbar", "focusFrame", "castBar", "isShown");

	checkbutton = _G[prefix.."ShowCastHistory"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "showCastHistory", "focusFrame", "castHistory", "isShown");	

	checkbutton = _G[prefix.."ShowAuras"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "showAuras", "focusFrame", "auraFrame", "isShown");
	
	checkbutton = nil;
	
	
	-- Initialise Editboxes
	editbox = _G[prefix.."HealthBarText"];
	ALUF_Options_EditBoxInitialise(editbox, "shownTextinHealthBar:", "focusFrame", nil, "healthBarTextString");

	editbox = _G[prefix.."PowerBarText"];
	ALUF_Options_EditBoxInitialise(editbox, "shownTextinPowerBar:", "focusFrame", nil, "powerBarTextString");
	
	-- Initialise Sliders
	slider = _G[prefix.."CastHistoryShownIcons"];
	ALUF_Options_SliderInitialise(slider, "maxCastHistoryIcons", "focusFrame", "castHistory", "shownIcons")

	slider = _G[prefix.."FrameScale"];
	slider.valueFactor = 0.1;
	ALUF_Options_SliderInitialise(slider, "frameScale", "focusFrame", nil, "scale")
	
	-- Initialise DropDown menus
	dropdown = _G[prefix.."PortraitType"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["portraitType"];
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = _G[prefix.."Icon1"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon1Type"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);

	dropdown = _G[prefix.."Icon2"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon2Type"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);

	dropdown = _G[prefix.."HealthBarColour"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["healthBarColourMode"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);

	dropdown = _G[prefix.."NameColour"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["nameColourMode"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = _G[prefix.."CastBarPosition"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castBar"]["position"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = _G[prefix.."AuraPosition"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["auraFrame"]["position"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = nil;
end

function ALUF_OptionsFocusFrame_OnEvent(self, event, ...)
	local arg1 = ...;
	
	if ( event == "ADDON_LOADED" and arg1 == addonName ) then
		ALUF_OptionsFocusFrame_Initialise(self)
	end

end

function ALUF_OptionsFocusFrame_OnShow(self)
	local prefix = self:GetName();
	local isEnabledCheckbutton = _G[prefix.."IsEnabled"];
	local framelockCheckbutton = _G[prefix.."IsLocked"];
	local frameScale = _G[prefix.."FrameScale"];
	if ( InCombatLockdown() ) then
		isEnabledCheckbutton:Disable();
		framelockCheckbutton:Disable();
		frameScale:Disable();
		ArenaLive_SystemMessage(L["inCombatLockdown"]);
	else
		isEnabledCheckbutton:Enable();
		framelockCheckbutton:Enable();
		frameScale:Enable();
	end
end


function ALUF_OptionsFocusFrame_Okay(self)
	local prefix = self:GetName();
	local frame;
	if ( not InCombatLockdown() ) then	
		-- CHECKBUTTONS
		frame = _G[prefix.."IsEnabled"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["enabled"] = frame:GetChecked();
		
		frame = _G[prefix.."IsLocked"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["isLocked"] = frame:GetChecked();
		
		frame = _G[prefix.."ShowCastBar"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castBar"]["isShown"] = frame:GetChecked();
		
		frame = _G[prefix.."ShowCastHistory"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castHistory"]["isShown"] = frame:GetChecked();
		
		frame = _G[prefix.."ShowAuras"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["auraFrame"]["isShown"] = frame:GetChecked();
		
		
		-- EDITBOXES
		frame = _G[prefix.."HealthBarText"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["healthBarTextString"] = frame:GetText();
		
		frame = _G[prefix.."PowerBarText"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["powerBarTextString"] = frame:GetText();
		
		
		-- SLIDERS
		frame = _G[prefix.."CastHistoryShownIcons"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castHistory"]["shownIcons"] = ALUF_Options_SliderGetValue(frame);
		
		frame = _G[prefix.."FrameScale"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["scale"] = ALUF_Options_SliderGetValue(frame);
		
		
		-- DROPDOWN MENUS
		frame = _G[prefix.."PortraitType"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["portraitType"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."Icon1"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon1Type"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."Icon2"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon2Type"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."HealthBarColour"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["healthBarColourMode"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."NameColour"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["nameColourMode"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."CastBarPosition"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castBar"]["position"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."AuraPosition"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["auraFrame"]["position"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = nil;
		
		-- Updapte the frame and saved variables
		ArenaLive_Database_UpdateSavedVariables(addonName, ArenaLiveUnitFrames_SavedVariables);
		
		local scale = ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["scale"];

		ALUF_FocusFrame:SetScale(scale);

		ArenaLive_UnitFrame_Update(ALUF_FocusFrame);
		ArenaLive_Icon_Update(ALUF_FocusFrameIcon1);
		ArenaLive_Icon_Update(ALUF_FocusFrameIcon2);
		ALUF_FocusFrame_AdjustAttachments(ALUF_FocusFrame);
	else
		ALUF_OptionsFocusFrame_Cancel(self)
	end
end



function ALUF_OptionsFocusFrame_Cancel(self)
	
	local prefix = self:GetName();
	local frame;
	
	-- CHECKBUTTONS
	frame = _G[prefix.."IsEnabled"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["enabled"]);
	
	frame = _G[prefix.."IsLocked"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["isLocked"]);
	
	frame = _G[prefix.."ShowCastBar"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castBar"]["isShown"]);
	
	frame = _G[prefix.."ShowCastHistory"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castHistory"]["isShown"]);
	
	frame = _G[prefix.."ShowAuras"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["auraFrame"]["isShown"]);
	
	
	-- EDITBOXES
	frame = _G[prefix.."HealthBarText"];
	frame:SetText(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["healthBarTextString"]);
	
	frame = _G[prefix.."PowerBarText"];
	frame:SetText(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["powerBarTextString"]);
	
	
	-- SLIDERS
	frame = _G[prefix.."CastHistoryShownIcons"];
	ALUF_Options_SliderSetValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castHistory"]["shownIcons"]);
	
	frame = _G[prefix.."FrameScale"];
	ALUF_Options_SliderSetValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["scale"]);
	
	
	-- DROPDOWN MENUS
	frame = _G[prefix.."PortraitType"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["portraitType"]);
	
	frame = _G[prefix.."Icon1"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon1Type"]);
	
	frame = _G[prefix.."Icon2"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["icon2Type"]);
	
	frame = _G[prefix.."HealthBarColour"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["healthBarColourMode"]);
	
	frame = _G[prefix.."NameColour"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["nameColourMode"]);
	
	frame = _G[prefix.."CastBarPosition"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["castBar"]["position"]);
	
	frame = _G[prefix.."AuraPosition"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["focusFrame"]["auraFrame"]["position"]);
	
	frame = nil;
end