local addonName, L = ...;

function ALUF_OptionsPetFrame_OnLoad(self)
	-- Create a sub panel in ArenaLiveUnitFrame addon panel
	self.name= L["petFrame"];
	self.okay = ALUF_OptionsPetFrame_Okay;
	self.cancel = ALUF_OptionsPetFrame_Cancel;
	self.parent = "ArenaLiveUnitFrames";
	InterfaceOptions_AddCategory(self);	

	-- Set Localisation:
	ALUF_PetFrame_OptionsTitle:SetText(L["ALUFPetFrameTitle"]);
	ALUF_PetFrame_OptionsCastBarTitle:SetText(L["castBar:"]);
	ALUF_PetFrame_OptionsAuraTitle:SetText(L["auras:"]);
	
	self:RegisterEvent("ADDON_LOADED");
end

function ALUF_OptionsPetFrame_Initialise(self)
	local prefix = self:GetName();
	local checkbutton, editbox, slider, dropdown, selectedValue;
	
	-- Initialise Checkbuttons
	checkbutton = _G[prefix.."IsEnabled"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "enableFrame", "petFrame", nil, "enabled");
	
	checkbutton = _G[prefix.."IsLocked"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "lockFrame", "petFrame", nil, "isLocked");
	
	checkbutton = _G[prefix.."ShowCastBar"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "showCastbar", "petFrame", "castBar", "isShown");	

	checkbutton = _G[prefix.."ShowAuras"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "showAuras", "petFrame", "auraFrame", "isShown");
	
	checkbutton = nil;
	
	
	-- Initialise Editboxes
	editbox = _G[prefix.."HealthBarText"];
	ALUF_Options_EditBoxInitialise(editbox, "shownTextinHealthBar:", "petFrame", nil, "healthBarTextString");

	editbox = _G[prefix.."PowerBarText"];
	ALUF_Options_EditBoxInitialise(editbox, "shownTextinPowerBar:", "petFrame", nil, "powerBarTextString");
	
	-- Initialise Sliders
	slider = _G[prefix.."FrameScale"];
	slider.valueFactor = 0.1;
	ALUF_Options_SliderInitialise(slider, "frameScale", "petFrame", nil, "scale")
	
	-- Initialise DropDown menus
	dropdown = _G[prefix.."CastBarPosition"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["castBar"]["position"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = _G[prefix.."AuraPosition"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["auraFrame"]["position"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = nil;
end

function ALUF_OptionsPetFrame_OnEvent(self, event, ...)
	local arg1 = ...;
	
	if ( event == "ADDON_LOADED" and arg1 == addonName ) then
		ALUF_OptionsPetFrame_Initialise(self)
	end

end

function ALUF_OptionsPetFrame_OnShow(self)
	local prefix = self:GetName();
	local isEnabledCheckbutton = _G[prefix.."IsEnabled"];
	local framelockCheckbutton = _G[prefix.."IsLocked"];
	local frameScale = _G[prefix.."FrameScale"];
	if ( InCombatLockdown() ) then
		isEnabledCheckbutton:Disable();
		framelockCheckbutton:Disable();
		frameScale:Disable();
		ArenaLive_SystemMessage(L["inCombatLockdown"]);
	else
		isEnabledCheckbutton:Enable();
		framelockCheckbutton:Enable();
		frameScale:Enable();
	end
end


function ALUF_OptionsPetFrame_Okay(self)
	local prefix = self:GetName();
	local frame;
	
	if ( not InCombatLockdown() ) then
		-- CHECKBUTTONS
		frame = _G[prefix.."IsEnabled"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["enabled"] = frame:GetChecked();
		
		frame = _G[prefix.."IsLocked"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["isLocked"] = frame:GetChecked();
		
		frame = _G[prefix.."ShowCastBar"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["castBar"]["isShown"] = frame:GetChecked();
		
		frame = _G[prefix.."ShowAuras"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["auraFrame"]["isShown"] = frame:GetChecked();
		
		
		-- EDITBOXES
		frame = _G[prefix.."HealthBarText"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["healthBarTextString"] = frame:GetText();
		
		frame = _G[prefix.."PowerBarText"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["powerBarTextString"] = frame:GetText();
		
		
		-- SLIDERS	
		frame = _G[prefix.."FrameScale"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["scale"] = ALUF_Options_SliderGetValue(frame);
		
		
		-- DROPDOWN MENUS		
		frame = _G[prefix.."CastBarPosition"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["castBar"]["position"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."AuraPosition"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["auraFrame"]["position"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = nil;
		
		-- Updapte the frame and saved variables
		ArenaLive_Database_UpdateSavedVariables(addonName, ArenaLiveUnitFrames_SavedVariables);
		
		local scale = ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["scale"];
		ALUF_PetFrame:SetScale(scale);
		
		ArenaLive_UnitFrame_Update(ALUF_PetFrame);
		ALUF_PetFrame_AdjustAttachments(ALUF_PetFrame);
	else
		ALUF_OptionsPetFrame_Cancel(self)
	end
end



function ALUF_OptionsPetFrame_Cancel(self)
	
	local prefix = self:GetName();
	local frame;
	
	-- CHECKBUTTONS
	frame = _G[prefix.."IsEnabled"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["enabled"]);
	
	frame = _G[prefix.."IsLocked"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["isLocked"]);
	
	frame = _G[prefix.."ShowCastBar"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["castBar"]["isShown"]);
	
	frame = _G[prefix.."ShowAuras"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["auraFrame"]["isShown"]);
	
	
	-- EDITBOXES
	frame = _G[prefix.."HealthBarText"];
	frame:SetText(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["healthBarTextString"]);
	
	frame = _G[prefix.."PowerBarText"];
	frame:SetText(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["powerBarTextString"]);
	
	
	-- SLIDERS
	frame = _G[prefix.."FrameScale"];
	ALUF_Options_SliderSetValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["scale"]);
	
	
	-- DROPDOWN MENUS
	frame = _G[prefix.."CastBarPosition"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["castBar"]["position"]);
	
	frame = _G[prefix.."AuraPosition"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["petFrame"]["auraFrame"]["position"]);
	
	frame = nil;
end